==> invenio-vocabularies-0.3.3.tar.gz: invenio-vocabularies-0.3.3/tests/services/test_permissions.py <==
# -*- coding: utf-8 -*-
#
# This file is part of Invenio.
# Copyright (C) 2020-2021 CERN.
#
# Invenio-Vocabularies is free software; you can redistribute it and/or
# modify it under the terms of the MIT License; see LICENSE file for more
# details.

"""Test the vocabulary service."""

import pytest
from flask_principal import Identity, PermissionDenied
from invenio_access.permissions import any_user, system_identity

from invenio_vocabularies.records.api import Vocabulary


#
# Fixtures
#
@pytest.fixture()
def anyuser_idty():
    """Simple identity to interact with the service."""
    identity = Identity(1)
    identity.provides.add(any_user)
    return identity


#
# Tests
#
def test_permissions_readonly(anyuser_idty, lang_type, lang_data, service):
    """Read-only permission test.

    These tests will eventually need to be rewritten once a more advanced
    permission policy is put in place. Currently the permission policy only
    allows a system process to create/update/delete vocabularies.
    """
    # Create - only system allowed
    pytest.raises(PermissionDenied, service.create, anyuser_idty, lang_data)
    item = service.create(system_identity, lang_data)
    id_ = item.id

    # Read - both allowed
    item = service.read(('languages', id_), anyuser_idty, lang_data)
    item = service.read(('languages', id_), system_identity, lang_data)

    # Refresh index to make changes live.
    Vocabulary.index.refresh()

    # Search - both allowed
    res = service.search(
        anyuser_idty, type='languages', q=f"id:{id_}", size=25, page=1)
    assert res.total == 1
    res = service.search(
        system_identity, type='languages', q=f"id:{id_}", size=25, page=1)
    assert res.total == 1

    # Update - only system allowed
    data = item.data
    data['title']['en'] = 'New title'
    pytest.raises(
        PermissionDenied, service.update, ('languages', id_), anyuser_idty,
        data)
    service.update(('languages', id_), system_identity, data)

    # Delete - only system allowed
    pytest.raises(
        PermissionDenied, service.delete, ('languages', id_), anyuser_idty)
    service.delete(('languages', id_), system_identity)

==> invenio-vocabularies-0.7.3.tar.gz: invenio-vocabularies-0.7.3/tests/services/test_permissions.py <==
# -*- coding: utf-8 -*-
#
# This file is part of Invenio.
# Copyright (C) 2020-2021 CERN.
#
# Invenio-Vocabularies is free software; you can redistribute it and/or
# modify it under the terms of the MIT License; see LICENSE file for more
# details.

"""Test the vocabulary service."""

import pytest
from flask_principal import Identity, PermissionDenied
from invenio_access.permissions import any_user, system_identity

from invenio_vocabularies.records.api import Vocabulary


#
# Fixtures
#
@pytest.fixture()
def anyuser_idty():
    """Simple identity to interact with the service."""
    identity = Identity(1)
    identity.provides.add(any_user)
    return identity


#
# Tests
#
def test_permissions_readonly(anyuser_idty, lang_type, lang_data, service):
    """Read-only permission test.

    These tests will eventually need to be rewritten once a more advanced
    permission policy is put in place. Currently the permission policy only
    allows a system process to create/update/delete vocabularies.
    """
    # Create - only system allowed
    pytest.raises(PermissionDenied, service.create, anyuser_idty, lang_data)
    item = service.create(system_identity, lang_data)
    id_ = item.id

    # Read - both allowed
    item = service.read(('languages', id_), anyuser_idty)
    item = service.read(('languages', id_), system_identity)

    # Refresh index to make changes live.
    Vocabulary.index.refresh()

    # Search - both allowed
    res = service.search(
        anyuser_idty, type='languages', q=f"id:{id_}", size=25, page=1)
    assert res.total == 1
    res = service.search(
        system_identity, type='languages', q=f"id:{id_}", size=25, page=1)
    assert res.total == 1

    # Update - only system allowed
    data = item.data
    data['title']['en'] = 'New title'
    pytest.raises(
        PermissionDenied, service.update, ('languages', id_), anyuser_idty,
        data)
    service.update(('languages', id_), system_identity, data)

    # Delete - only system allowed
    pytest.raises(
        PermissionDenied, service.delete, ('languages', id_), anyuser_idty)
    service.delete(('languages', id_), system_identity)
